@@ -106,7 +106,12 @@ class Parser(ParserBase):
         self._scope = scope
 
     def on_snippet(
-        self, snippet_prefix: str, snippet_name: str, snippet_arg: Json, src_path: Path, fh: TextIOWrapper
+        self,
+        snippet_prefix: str,
+        snippet_name: str,
+        snippet_arg: Json,
+        src_path: Path,
+        fh: TextIOWrapper,
     ):
         logger.debug(f"on_snippet {snippet_name!r} called")
         snippet_fn: Union[SnippetFn, None] = self._snippets_scope.get(
@@ -125,6 +130,7 @@ class Parser(ParserBase):
         scope["$snippets"] = self._snippets_scope.derive()
         try:
             snippet_fn(emitter, scope, snippet_arg)
+            emitter.freshline()
         except Exception as e:
             logger.error(
                 f"error executing snippet {snippet_name!r} in {fpath!s}", exc_info=True
